Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(854)

Unified Diff: runtime/include/dart_api.h

Issue 2512483002: Support reloading from source on top of a script snapshot. (Closed)
Patch Set: ... Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/isolate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h
index 1a09f7bf27249509cbf08207b3f30a58bf1774c2..a085a724bf47fe05981d292b3f56300031dd09c4 100644
--- a/runtime/include/dart_api.h
+++ b/runtime/include/dart_api.h
@@ -2734,7 +2734,8 @@ typedef enum {
* Dart_kScriptTag
*
* This tag indicates that the root script should be loaded from
* 'url'. The 'library' parameter will always be null. Once the root
* script is loaded, the embedder should call Dart_LoadScript to
* install the root script in the VM. The return value should be an
* error or null.
@@ -2753,9 +2754,10 @@ typedef enum {
* call Dart_LoadLibrary to provide the script source to the VM. The
* return value should be an error or null.
*/
-typedef Dart_Handle (*Dart_LibraryTagHandler)(Dart_LibraryTag tag,
- Dart_Handle library,
- Dart_Handle url);
+typedef Dart_Handle (*Dart_LibraryTagHandler)(
+ Dart_LibraryTag tag,
+ Dart_Handle library_or_package_map_url,
+ Dart_Handle url);
/**
* Sets library tag handler for the current isolate. This handler is
« no previous file with comments | « no previous file | runtime/vm/isolate.h » ('j') | no next file with comments »
@@ -2734,7 +2734,8 @@ typedef enum {
*
* This tag indicates that the root script should be loaded from
- * 'url'. The 'library' parameter will always be null. Once the root
+ * 'url'. If the 'library' parameter is not null, it is the url of the
+ * package map that should be used when loading. Once the root
* script is loaded, the embedder should call Dart_LoadScript to
* install the root script in the VM. The return value should be an

Powered by Google App Engine
This is Rietveld 408576698